..
    This file is part of Invenio.
    Copyright (C) 2015 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.


Authors
=======
Invenio is being co-developed by an international collaboration
comprising institutes such as CERN, DESY, EPFL, FNAL, SLAC.

You can contact us at <info@invenio-software.org>.

Active contributors:

* Adrian Pawel Baran <adrian.pawel.baran@cern.ch>
* Alexander Wagner <alexander.wagner@desy.de>
* Annette Holtkamp <annette.holtkamp@cern.ch>
* Cornelia Plott <c.plott@fz-juelich.de>
* Cristian Bacchi <cristian.bacchi@gmail.com>
* Dan Michael O. Heggø <danmichaelo@gmail.com>
* Daniel Lovasko <daniel.lovasko@cern.ch>
* Dimitrios Semitsoglou-Tsiapos <dsemitso@cern.ch>
* Eamonn Maguire <eamonnmag@gmail.com>
* Esteban J. G. Gabancho <esteban.jose.garcia.gabancho@cern.ch>
* Ferran Jorba <Ferran.Jorba@uab.cat>
* Flavio Costa <flavio.costa@cern.ch>
* Gilles Louppe <g.louppe@gmail.com>
* Guillaume Lastecoueres <PX9e@gmx.fr>
* Harris Tzovanakis <me@drjova.com>
* Ivan Masár <helix84@centrum.sk>
* Jacopo Notarstefano <jacopo.notarstefano@cern.ch>
* Jan Aage Lavik <jan.age.lavik@cern.ch>
* Jan Stypka <jan.stypka@cern.ch>
* Javier Martin <javier.martin.montull@cern.ch>
* Jiri Kuncar <jiri.kuncar@cern.ch>
* Jocelyne Jerdelet <jocelyne.jerdelet@cern.ch>
* Joe MacMahon <joe.macmahon@cern.ch>
* Jochen Klein <klein.jochen@gmail.com>
* Johnny Mariéthoz <johnny.mariethoz@rero.ch>
* Kenneth Hole <kenneth@tind.io>
* Kirsten Sachs <kirsten.sachs@desy.de>
* Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
* Laura Rueda <laura.rueda@cern.ch>
* Leonardo Rossi <leonardo.r@cern.ch>
* Ludmila Marian <ludmila.marian@gmail.com>
* Marco Neumann <marco@crepererum.net>
* Marios Kogias <marioskogias@gmail.com>
* Mateusz Susik <mateusz.susik@cern.ch>
* Miguel Martín <miguelm@unizar.es>
* Nicolas Harraudeau <nicolas.harraudeau@cern.ch>
* Nikolaos Kasioumis <nikolaos.kasioumis@cern.ch>
* Øystein Blixhavn <oystein@blixhavn.no>
* Pamfilos Fokianos <pamfilos.fokianos@cern.ch>
* Pedro Gaudencio <pmgaudencio@gmail.com>
* Petr Brož <petr.broz@heaven-industries.com>
* Petros Ioannidis <petros.ioannidis@cern.ch>
* Roman Chyla <roman.chyla@cern.ch>
* Sami Hiltunen <sami.mikael.hiltunen@cern.ch>
* Samuele Kaplun <samuele.kaplun@cern.ch>
* Sebastian Witowski <sebastian.witowski@cern.ch>
* Stefan Hesselbach <s.hesselbach@gsi.de>
* Theodoropoulos Theodoros <theod@lib.auth.gr>
* Tibor Simko <tibor.simko@cern.ch>
* Thorsten Schwander <thorsten.schwander@gmail.com>
* Wojciech Ziolek <wojciech.ziolek@cern.ch>

Past contributors:

* Adrian-Tudor Panescu <adrian.tudor.panescu@cern.ch>
* Alberto Pepe <alberto.pepe@cern.ch>
* Alessio Deiana <alessio.deiana@cern.ch>
* Alexandra Silva <xana@correio.ci.uminho.pt>
* Alper Cinar <alper@srdc.com.tr>
* Anna Afshar <anna.afsharghasemlouy@epfl.ch>
* Antonios Manaras <antonios.manaras@cern.ch>
* Artem Tsikiridis <artem.tsikiridis@cern.ch>
* Avraam Tsantekidis <avraam.tsantekidis@cern.ch>
* Axel Voitier <axel.voitier@gmail.com>
* Benoit Thiell <benoit.thiell@cern.ch>
* Björn Oltmanns <bjoern.oltmanns@gmail.com>
* Carmen Alvarez Perez <carmen.alvarez.perez@cern.ch>
* Christopher Dickinson <christopher.dickinson@cern.ch>
* Christopher Hayward <christopher.james.hayward@cern.ch>
* Christopher Parker <chris.parker.za@gmail.com>
* Daniel Stanculescu <daniel.stanculescu@cern.ch>
* David Bengoa <david.bengoa.rocandio@cern.ch>
* Diane Berkovits <diane.berkovits@cern.ch>
* Dinos Kousidis <konstantinos.kousidis@cern.ch>
* Eduardo Margallo <eduardo.margallo@cern.ch>
* Eirini Psallida <eirini.psallida@cern.ch>
* Erik Simon <erik.simon@unine.ch>
* Eric Stahl <eric.stahl@utbm.fr>
* Fabio Souto <fsoutomoure@gmail.com>
* Federico Poli <federico.poli@cern.ch>
* Franck Grenier <franckgrenier@wanadoo.fr>
* Frederic Gobry <frederic.gobry@epfl.ch>
* Fredrik Nygård Carlsen <me@frecar.no>
* Gabriel Hase <gabriel.hase@cern.ch>
* Georgios Kokosioulis <giokokos@gmail.com>
* Georgios Papoutsakis <georgios.papoutsakis@cern.ch>
* Gerrit Rindermann <Gerrit.Rindermann@cern.ch>
* giannistsan <tsanakts.10@gmail.com>
* Giovanni Di Milia <gdimilia@cfa.harvard.edu>
* Glenn Gard <glenng4@aol.com>
* Graham R. Armstrong <graham.richard.armstrong@cern.ch>
* Gregory Favre <gregory.favre@cern.ch>
* Grzegorz Szpura <grzegorz.szpura@cern.ch>
* Guotie <guotie.9@gmail.com>
* Eduardo Benavidez <eduardo.benavidez@gmail.com>
* Hector Sanchez <hector.sanchez@cern.ch>
* Henning Weiler <henning.weiler@cern.ch>
* Jaime Garcia Llopis <jaime.garcia.llopis@cern.ch>
* Jake Cowton <jake.calum.cowton@cern.ch>
* Jan Brice Krause <jan.brice.krause@cern.ch>
* Jan Iwaszkiewicz <jan.iwaszkiewicz@cern.ch>
* Jay Luker <lbjay@reallywow.com>
* Jerome Caffaro <jerome.caffaro@cern.ch>
* João Batista <jnfbatista@gmail.com>
* Joaquim Rodrigues Silvestre <joaquim.rodrigues.silvestre@cern.ch>
* Joe Blaylock <jrbl@slac.stanford.edu>
* Joël Vogt <joel.vogt@unifr.ch>
* Johann C. Rocholl <johann@browsershots.org>
* Jorge Aranda Sumarroca <jorge.aranda.sumarroca@cern.ch>
* Juan Francisco Pereira Corral <juan.francisco.pereira.corral@cern.ch>
* Julio Pernia Aznar <jpernia@altransdb.com>
* Juliusz Sompolski <julsomp@gmail.com>
* Jurga Girdzijauskaite <jurga.gird@gmail.com>
* Kamil Neczaj <kamil.neczaj@cern.ch>
* Kevin Bowrin <kjbowrin@gmail.com>
* Kevin M. Flannery <flannery@fnal.gov>
* Kevin Sanders <kevin.sanders@cern.ch>
* Konstantinos Kostis <konstantinos.kostis@cern.ch>
* Konstantinos Kousidis <dinossimpson@pb-d-128-141-29-229.cern.ch>
* Konstantinos Ntemagkos <konstantinos.ntemagkos@cern.ch>
* Krzysztof Jedrzejek <krzysztof.jedrzejek@cern.ch>
* Krzysztof Lis <krzysztof.lis@cern.ch>
* Kyriakos Liakopoulos <kyriakos.liakopoulos@cern.ch>
* Lars Christian Raae <lars.christian.raae@cern.ch>
* Lewis Barnes <lewis.barnes@cern.ch>
* Luke Andrew Smith <smithey_72@hotmail.com>
* Maja Gracco <maja.gracco@cern.ch>
* Markus Goetz <murxman@gmail.com>
* Marcus Johansson <marcus.johansson@cern.ch>
* Marko Niinimaki <manzikki@gmail.com>
* Martin Vesely <martin.vesely@cern.ch>
* Mathieu Barras <mbarras@gmail.com>
* Miguel Martinez Pedreira <miguel.martinez.pedreira@cern.ch>
* Mikael Karlsson <i8myshoes@gmail.com>
* Mikael Vik <mikael.vik@cern.ch>
* Mike Marino <mmarino@gmail.com>
* Mike Sullivan <sul@slac.stanford.edu>
* Minn Soe <minn.soe@cern.ch>
* Nicholas Robinson <nicholas.robinson@cern.ch>
* Nikola Yolov <nikola.yolov@cern.ch>
* Nikolaos Kalodimas <nikolaos.kalodimas@cern.ch>
* Nikolay Dyankov <ndyankov@gmail.com>
* Nino Jejelava <nino.jejelava@gmail.com>
* Olivier Canévet <olivier.canevet@cern.ch>
* Olivier Serres <olivier.serres@gmail.com>
* Øyvind Østlund <oyvind.ostlund@cern.ch>
* Pablo Vázquez Caderno <pcaderno@cern.ch>
* Patrick Glauner <patrick.oliver.glauner@cern.ch>
* Paulo Cabral <paulo.cabral@cern.ch>
* Peter Halliday <phalliday@cornell.edu>
* Piotr Praczyk <piotr.praczyk@piotr.praczyk@gmail.com>
* Radoslav Ivanov <radoslav.ivanov@cern.ch>
* Raja Sripada <raja.sripada@cern.ch>
* Raquel Jimenez Encinar <raquel.jimenez.encinar@cern.ch>
* Richard Owen <ro@tes.la>
* Roberta Faggian <roberta.faggian@cern.ch>
* Ruben Pollan <ruben.pollan@cern.ch>
* Samuele Carli <samuele.carli@cern.ch>
* Stamen Todorov Peev <stamen.peev@cern.ch>
* Stephane Martin <stephane.martin@epfl.ch>
* Thierry Thomas <thierry@FreeBSD.org>
* Thomas Baron <thomas.baron@cern.ch>
* Thomas Karampelas <thomas.karampelas@cern.ch>
* Thomas McCauley <thomas.mccauley@cern.ch>
* Tiberiu Dondera <tiberiu.dondera@pronet-consulting.com>
* Tony Ohls <tony.ohls@cern.ch>
* Tony Osborne <tony.osborne@cern.ch>
* Travis Brooks <travis@slac.stanford.edu>
* Trond Aksel Myklebust <trond.aksel.myklebust@cern.ch>
* Valkyrie Savage <vasavage@gmail.com>
* Vasanth Venkatraman <vasanth.venkatraman@cern.ch>
* Vasyl Ostrovskyi <vo@imath.kiev.ua>
* Victor Engmark <victor.engmark@cern.ch>
* Yannick Tapparel <yannick.tapparel@cern.ch>
* Yoan Blanc <yoan.blanc@cern.ch>
* Yohann Paris <yohann.paris@cern.ch>
* Željko Kraljević <w.kraljevic@gmail.com>

See also THANKS file.
